==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebGridRowEditActionsTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridRowEditActionsTemplateContextDescription } from "./WebGridRowEditActionsTemplateContextDescription";
/**
 * @hidden
 */
export let WebGridRowEditActionsTemplateContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridRowEditActionsTemplateContextDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridRowEditActionsTemplateContextDescriptionMetadata.a == null) {
                WebGridRowEditActionsTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridRowEditActionsTemplateContextDescriptionMetadata.c(WebGridRowEditActionsTemplateContextDescriptionMetadata.a);
            }
            if (a.j(WebGridRowEditActionsTemplateContextDescriptionMetadata.a)) {
                return;
            }
            a.y(WebGridRowEditActionsTemplateContextDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridRowEditActionsTemplateContext");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
        }
        static d(a) {
            WebGridRowEditActionsTemplateContextDescriptionMetadata.b(a);
            a.aa("WebGridRowEditActionsTemplateContext", () => new WebGridRowEditActionsTemplateContextDescription());
            a.z("WebGridRowEditActionsTemplateContext", WebGridRowEditActionsTemplateContextDescriptionMetadata.a);
        }
    }
    WebGridRowEditActionsTemplateContextDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridRowEditActionsTemplateContextDescriptionMetadata, 'WebGridRowEditActionsTemplateContextDescriptionMetadata');
    WebGridRowEditActionsTemplateContextDescriptionMetadata.a = null;
    return WebGridRowEditActionsTemplateContextDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebGridRowEditActionsTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridRowEditActionsTemplateContextDescription } from "./WebGridRowEditActionsTemplateContextDescription";
/**
 * @hidden
 */
export let WebGridRowEditActionsTemplateContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridRowEditActionsTemplateContextDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridRowEditActionsTemplateContextDescriptionMetadata.a == null) {
                WebGridRowEditActionsTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridRowEditActionsTemplateContextDescriptionMetadata.c(WebGridRowEditActionsTemplateContextDescriptionMetadata.a);
            }
            if (a.k(WebGridRowEditActionsTemplateContextDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebGridRowEditActionsTemplateContextDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridRowEditActionsTemplateContext");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebGridRowEditActionsTemplateContextDescriptionMetadata.b(a);
            a.ac("WebGridRowEditActionsTemplateContext", () => new WebGridRowEditActionsTemplateContextDescription());
            a.ab("WebGridRowEditActionsTemplateContext", WebGridRowEditActionsTemplateContextDescriptionMetadata.a);
        }
    }
    WebGridRowEditActionsTemplateContextDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridRowEditActionsTemplateContextDescriptionMetadata, 'WebGridRowEditActionsTemplateContextDescriptionMetadata');
    WebGridRowEditActionsTemplateContextDescriptionMetadata.a = null;
    return WebGridRowEditActionsTemplateContextDescriptionMetadata;
})();
